@@ -1,13 +1,14 @@
 # nocov start
-.onLoad <- function(libname,pkgname){
+.onLoad <- function(libname, pkgname){
 
   memoise_option <- getOption("ggpath.cache", default = "memory")
 
   if(!memoise_option %in% c("memory", "filesystem", "off")) memoise_option <- "memory"
 
   if(memoise_option == "filesystem"){
-    cache_dir <- rappdirs::user_cache_dir(appname = "ggpath")
-    dir.create(cache_dir, recursive = TRUE, showWarnings = FALSE)
+    backports::import(pkgname, "R_user_dir")
+    cache_dir <- R_user_dir("ggpath", "cache")
+    if (!dir.exists(cache_dir)) dir.create(cache_dir, recursive = TRUE, showWarnings = FALSE)
     cache <- cachem::cache_disk(dir = cache_dir)
   }
 
@@ -23,7 +24,7 @@
 .onAttach <- function(libname, pkgname){
 
   # validate ggpath.cache
-  memoise_option <- getOption("ggpath.cache",default = "memory")
+  memoise_option <- getOption("ggpath.cache", default = "memory")
 
   if (!memoise_option %in% c("memory", "filesystem", "off")) {
     packageStartupMessage('Note: ggpath.cache is set to "',
